<?
/* navigation.php (c) 2000, 2001 Marco Pratesi (pratesi@telug.it) */

include("../application.inc.php");
?>

<html>
<head>
<link rel=StyleSheet href="<?=$CFG->wwwroot?>/styles/pgmarket.css" type="text/css">
</head>
<body class=nav topmargin="0" leftmargin="0" marginwidth="5" marginheight="10">

<h1><?=$Categories_Browsing?></h1>

<h2><? print_category_tree($id) ?></h2>

<table>
<tr>
<td class=label><?=$Categories?>:</td>
</tr>
<tr valign=top>
<td class=normal>
<?
build_category_navigator($categories);
$categories = ".Top^" . $CFG->wwwroot . "/shopping/^main\n" . $categories;
require("$CFG->libdir/treemenu.inc.php");
?>
</td>
</tr>
</table>

</body>
</html>
